# -*- coding: utf-8 -*-
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import ugettext_lazy as _

from .models import HighlightText


class HighlightPlugin(CMSPluginBase):
    name = _(u"highlight.js code")
    model = HighlightText
    render_template = "djangocms_highlightjs/code.html"
    text_enabled = True
    allow_children = False
    fields = ['theme', 'filename', 'body']

    def render(self, context, instance, placeholder):
        context.update({
            'instance': instance,
            'theme': 'djangocms_highlightjs/themes/%s.css' % instance.theme,
            'highlight': 'djangocms_highlightjs/js/highlight.pack.js'
        })
        return context
plugin_pool.register_plugin(HighlightPlugin)



# -*- coding: utf-8 -*-
from django.conf import settings


DEFAULT_THEMES = {
    'arta': 'Arta',
    'ascetic': 'Ascetic',
    'atelier-dune.dark': 'Atelier Dune - Dark',
    'atelier-dune.light': 'Atelier Dune - Light',
    'atelier-forest.dark': 'Atelier forest - Dark',
    'atelier-forest.light': 'Atelier forest - Light',
    'atelier-heath.dark': 'Atelier heath - Dark',
    'atelier-heath.light': 'Atelier heath - Light',
    'atelier-lakeside.dark': 'Atelier lakeside - Dark',
    'atelier-lakeside.light': 'Atelier lakeside - Light',
    'atelier-seaside.dark': 'Atelier seaside - Dark',
    'atelier-seaside.light': 'Atelier seaside - Light',
    'brown_paper': 'Brown Paper',
    'dark': 'Dark',
    'default': 'Default',
    'docco': 'Docco',
    'far': 'Far',
    'foundation': 'Foundation',
    'github': 'Github',
    'googlecode': 'GoogleCode',
    'idea': 'IDEA',
    'ir_black': 'Ir black',
    'magula': 'Magula',
    'mono-blue': 'Mono Blue',
    'monokai': 'Monokai',
    'monokai_sublime': 'Monokai sublime',
    'obsidian': 'Obsidian',
    'paraiso.dark': 'Paraiso - Dark',
    'paraiso.light': 'éaraiso - Light',
    'pojoaque': 'Pojoaque',
    'railscasts': 'RailsCasts',
    'rainbow': 'Rainbow',
    'school_book': 'School Book',
    'solarized_dark': 'Solarized - Dark',
    'solarized_light': 'Solarized - Light',
    'sunburst': 'Sunburst',
    'tomorrow': 'Tomorrow',
    'tomorrow-night-blue': 'Tomorrow night - Blug',
    'tomorrow-night-bright': 'Tomorrow night - Bright',
    'tomorrow-night': 'Tomorrow night',
    'tomorrow-night-eighties': 'Tomorrow night - Eighties',
    'vs': 'VS',
    'xcode': 'XCode',
    'zenburn': 'Zenburn',
}

HIGHLIGHT_THEME = getattr(settings, 'HIGHLIGHT_THEME', DEFAULT_THEMES)


# -*- coding: utf-8 -*-
from cms.models import CMSPlugin
from django.utils.translation import ugettext_lazy as _
from django.db import models

from .settings import HIGHLIGHT_THEME


class HighlightText(CMSPlugin):
    body = models.TextField(_('Code'))
    filename = models.CharField(_('Filename'), max_length=100, default='',
                                blank=True)
    theme = models.CharField(_(u'Rendering theme'), max_length=100,
                             choices=sorted(HIGHLIGHT_THEME.items()))

    def save(self, no_signals=False, *args, **kwargs):
        self.body = self.body.replace("\r", "")
        super(HighlightText, self).save(no_signals, *args, **kwargs)

    class Meta:
        verbose_name = _('Highligh.JS code')
        verbose_name_plural = _('Highligh.JS code')


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

import djangocms_highlightjs

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = djangocms_highlightjs.__version__

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='djangocms-highlightjs',
    version=version,
        description="""highlight.js plugin for django CMS 3.0""",
    long_description=readme + '\n\n' + history,
    author='Iacopo Spalletti',
    author_email='i.spalletti@nephila.it',
    url='https://github.com/nephila/djangocms-highlightjs',
    packages=[
        'djangocms_highlightjs',
    ],
    include_package_data=True,
    install_requires=[
        'django-sekizai',
        'django-cms>=3.0',
    ],
    license="BSD",
    zip_safe=False,
    keywords='djangocms-highlightjs',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
    ],
)